@@ -8,6 +8,7 @@
 
 const int32_t NULL_POINTER_ERROR = 100000;
 const int32_t MALLOC_ERROR = 200000;
+const int32_t VERSION_ERROR = 300000;
 const int32_t C_TRUE = 1;
 const int32_t C_FALSE = 0;
 
@@ -28,11 +29,10 @@ const MUMPS_INT MUMPS_ICNTL28_SEQUENTIAL = 1;       // section 5.4, page 33
 const double UMF_PRINT_LEVEL_SILENT = 0.0;   // page 116
 const double UMF_PRINT_LEVEL_VERBOSE = 2.0;  // page 116
 
-const MUMPS_INT MMP_SYMMETRY[4] = {
-    0,  // Auto => Unsymmetric
-    2,  // General symmetric
+const MUMPS_INT MMP_SYMMETRY[3] = {
     0,  // Unsymmetric
     1,  // Positive-definite symmetric
+    2,  // General symmetric
 };
 
 const MUMPS_INT MMP_ORDERING[10] = {
@@ -60,11 +60,9 @@ const MUMPS_INT MMP_SCALING[9] = {
     77,  // Sum => Auto
 };
 
-const double UMF_SYMMETRY[4] = {
-    UMFPACK_STRATEGY_AUTO,         // Auto
-    UMFPACK_STRATEGY_SYMMETRIC,    // General symmetric
+const double UMF_SYMMETRY[2] = {
     UMFPACK_STRATEGY_UNSYMMETRIC,  // Unsymmetric
-    UMFPACK_STRATEGY_SYMMETRIC,    // Positive-definite symmetric => General symmetric
+    UMFPACK_STRATEGY_SYMMETRIC,    // General symmetric
 };
 
 const double UMF_ORDERING[10] = {
